@@ -17,7 +17,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2008 - 2011 Red Hat, Inc.
+ * (C) Copyright 2008 - 2012 Red Hat, Inc.
  */
 
 #ifndef __PAGE_VPN_H__
@@ -34,7 +34,7 @@
 #define CE_PAGE_VPN(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CE_TYPE_PAGE_VPN, CEPageVpn))
 #define CE_PAGE_VPN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), CE_TYPE_PAGE_VPN, CEPageVpnClass))
 #define CE_IS_PAGE_VPN(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CE_TYPE_PAGE_VPN))
-#define CE_IS_PAGE_VPN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), CE_TYPE_PAGE_VPN))
+#define CE_IS_PAGE_VPN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CE_TYPE_PAGE_VPN))
 #define CE_PAGE_VPN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), CE_TYPE_PAGE_VPN, CEPageVpnClass))
 
 typedef struct {
@@ -50,12 +50,22 @@ GType ce_page_vpn_get_type (void);
 CEPage *ce_page_vpn_new (NMConnection *connection,
                          GtkWindow *parent,
                          NMClient *client,
+                         NMRemoteSettings *settings,
                          const char **out_secrets_setting_name,
                          GError **error);
 
+gboolean ce_page_vpn_can_export (CEPageVpn *page);
+
 void vpn_connection_new (GtkWindow *parent,
+                         const char *detail,
+                         NMRemoteSettings *settings,
                          PageNewConnectionResultFunc result_func,
-                         PageGetConnectionsFunc get_connections_func,
                          gpointer user_data);
 
+void vpn_connection_import (GtkWindow *parent,
+                            const char *detail,
+                            NMRemoteSettings *settings,
+                            PageNewConnectionResultFunc result_func,
+                            gpointer user_data);
+
 #endif  /* __PAGE_VPN_H__ */
