@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-/* NetworkManager Wireless Applet -- Display wireless access points and allow user control
+/* NetworkManager Applet -- allow user control over networking
  *
  * Dan Williams <dcbw@redhat.com>
  *
@@ -32,157 +32,6 @@
 
 #include "utils.h"
 
-static char *ignored_words[] = {
-	"Semiconductor",
-	"Components",
-	"Corporation",
-	"Communications",
-	"Company",
-	"Corp.",
-	"Corp",
-	"Co.",
-	"Inc.",
-	"Inc",
-	"Incorporated",
-	"Ltd.",
-	"Limited.",
-	"Intel?",
-	"chipset",
-	"adapter",
-	"[hex]",
-	"NDIS",
-	"Module",
-	NULL
-};
-
-static char *ignored_phrases[] = {
-	"Multiprotocol MAC/baseband processor",
-	"Wireless LAN Controller",
-	"Wireless LAN Adapter",
-	"Wireless Adapter",
-	"Network Connection",
-	"Wireless Cardbus Adapter",
-	"Wireless CardBus Adapter",
-	"54 Mbps Wireless PC Card",
-	"Wireless PC Card",
-	"Wireless PC",
-	"PC Card with XJACK(r) Antenna",
-	"Wireless cardbus",
-	"Wireless LAN PC Card",
-	"Technology Group Ltd.",
-	"Communication S.p.A.",
-	"Business Mobile Networks BV",
-	"Mobile Broadband Minicard Composite Device",
-	"Mobile Communications AB",
-	"(PC-Suite Mode)",
-	NULL
-};
-
-static char *
-fixup_desc_string (const char *desc)
-{
-	char *p, *temp;
-	char **words, **item;
-	GString *str;
-
-	p = temp = g_strdup (desc);
-	while (*p) {
-		if (*p == '_' || *p == ',')
-			*p = ' ';
-		p++;
-	}
-
-	/* Attempt to shorten ID by ignoring certain phrases */
-	for (item = ignored_phrases; *item; item++) {
-		guint32 ignored_len = strlen (*item);
-
-		p = strstr (temp, *item);
-		if (p)
-			memmove (p, p + ignored_len, strlen (p + ignored_len) + 1); /* +1 for the \0 */
-	}
-
-	/* Attmept to shorten ID by ignoring certain individual words */
-	words = g_strsplit (temp, " ", 0);
-	str = g_string_new_len (NULL, strlen (temp));
-	g_free (temp);
-
-	for (item = words; *item; item++) {
-		int i = 0;
-		gboolean ignore = FALSE;
-
-		if (g_ascii_isspace (**item) || (**item == '\0'))
-			continue;
-
-		while (ignored_words[i] && !ignore) {
-			if (!strcmp (*item, ignored_words[i]))
-				ignore = TRUE;
-			i++;
-		}
-
-		if (!ignore) {
-			if (str->len)
-				g_string_append_c (str, ' ');
-			g_string_append (str, *item);
-		}
-	}
-	g_strfreev (words);
-
-	temp = str->str;
-	g_string_free (str, FALSE);
-
-	return temp;
-}
-
-#define DESC_TAG "description"
-
-const char *
-utils_get_device_description (NMDevice *device)
-{
-	char *description = NULL;
-	const char *dev_product;
-	const char *dev_vendor;
-	char *product = NULL;
-	char *vendor = NULL;
-	GString *str;
-
-	g_return_val_if_fail (device != NULL, NULL);
-
-	description = g_object_get_data (G_OBJECT (device), DESC_TAG);
-	if (description)
-		return description;
-
-	dev_product = nm_device_get_product (device);
-	dev_vendor = nm_device_get_vendor (device);
-	if (!dev_product || !dev_vendor)
-		return NULL;
-
-	product = fixup_desc_string (dev_product);
-	vendor = fixup_desc_string (dev_vendor);
-
-	str = g_string_new_len (NULL, strlen (vendor) + strlen (product) + 1);
-
-	/* Another quick hack; if all of the fixed up vendor string
-	 * is found in product, ignore the vendor.
-	 */
-	if (!strcasestr (product, vendor)) {
-		g_string_append (str, vendor);
-		g_string_append_c (str, ' ');
-	}
-
-	g_string_append (str, product);
-	g_free (product);
-	g_free (vendor);
-
-	description = str->str;
-	g_string_free (str, FALSE);
-
-	g_object_set_data_full (G_OBJECT (device),
-	                        "description", description,
-	                        (GDestroyNotify) g_free);
-
-	return description;
-}
-
 /*
  * utils_ether_addr_valid
  *
